@@ -19,7 +19,7 @@ class MessageLabel : public QLabel
 public:
     QSize sizeHint() const override
     {
-        return fontMetrics().size(Qt::TextSingleLine, text());
+        return fontMetrics().size({}, text());
     }
 };
 DWIDGET_BEGIN_NAMESPACE
@@ -82,9 +82,8 @@ void DFloatingMessagePrivate::init()
         hBoxLayout->addWidget(closeButton);
 
         q->connect(closeButton, &DIconButton::clicked, q, [q]() {
-            if (q->windowHandle()) {
-                q->windowHandle()->close();
-            }
+            q->close();
+            
             if(ENABLE_ANIMATIONS && ENABLE_ANIMATION_MESSAGE) {
                 Q_EMIT q->messageClosed();
             }
